@@ -124,7 +124,7 @@ class PartitionFunction:
 
         with mpmath.workprec(self.precision):
             # shape = (# of configurations, # of volumes for each configuration)
-            exp = np.vectorize(bigfloat.exp)
+            exp = np.vectorize(mpmath.exp)
             return exp(-self.aligned_free_energies_for_each_configuration / (K * self.temperature))
 
     @LazyProperty
