@@ -158,8 +158,8 @@ class Plotter:
 
     def fv_pv(self):
         temperature_sample: list = list(map(float, self.user_settings['T4FV']))
-        f_min = np.array([], dtype=np.float64)
-        v_f_min = np.array([], dtype=np.float64)
+        f_min = []
+        v_f_min = []
 
         f_fitted_volume = self.user_settings['f_tv_fitted']
         volume_tv = pd.read_csv(f_fitted_volume, sep='\s+', index_col='T(K)\V(A^3)')
@@ -185,11 +185,10 @@ class Plotter:
 
         # Get the 'V0' and 'E0' for selected Temperatures
         for t in temperature_sample:
-            np.append(f_min, volume_vt.loc[:, volume_vt.columns == t].min().values)
-            np.append(v_f_min, volume_vt.loc[:, volume_vt.columns == t].idxmin().values)
+            f_min.append(volume_vt.loc[:, volume_vt.columns == t].min().values)
+            v_f_min.append(volume_vt.loc[:, volume_vt.columns == t].idxmin().values)
 
-        print(f_min)
-        print(v_f_min)
+        f_min, v_f_min = np.asfarray(f_min), np.asfarray(v_f_min)
 
         self.plot_to_file()
 
